@@ -8,12 +8,7 @@ import jsii
 import publication
 import typing_extensions
 
-from typeguard import check_type
-
-import aws_cdk.aws_dynamodb._jsii
-import aws_cdk.aws_iot._jsii
-import aws_cdk.aws_lambda._jsii
-import aws_cdk.core._jsii
+import aws_cdk._jsii
 import aws_solutions_constructs.aws_iot_lambda._jsii
 import aws_solutions_constructs.aws_lambda_dynamodb._jsii
 import aws_solutions_constructs.core._jsii
@@ -21,9 +16,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-solutions-constructs/aws-iot-lambda-dynamodb",
-    "1.180.0",
+    "2.1.0",
     __name__[0:-6],
-    "aws-iot-lambda-dynamodb@1.180.0.jsii.tgz",
+    "aws-iot-lambda-dynamodb@2.1.0.jsii.tgz",
 )
 
 __all__ = [
